parsers Package
===============

:mod:`parsers` Package
----------------------

.. automodule:: rdflib.plugins.parsers
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`hturtle` Module
---------------------

.. automodule:: rdflib.plugins.parsers.hturtle
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`notation3` Module
-----------------------

.. automodule:: rdflib.plugins.parsers.notation3
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`nquads` Module
--------------------

.. automodule:: rdflib.plugins.parsers.nquads
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`nt` Module
----------------

.. automodule:: rdflib.plugins.parsers.nt
    :members:
    :undoc-members:
    :show-inheritance:
    :exclude-members: __dict__,__weakref__

:mod:`ntriples` Module
----------------------

.. automodule:: rdflib.plugins.parsers.ntriples
    :members:
    :undoc-members:
    :show-inheritance:
    :exclude-members: __dict__,__weakref__

:mod:`rdfxml` Module
--------------------

.. automodule:: rdflib.plugins.parsers.rdfxml
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`structureddata` Module
----------------------------

.. automodule:: rdflib.plugins.parsers.structureddata
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`trix` Module
------------------

.. automodule:: rdflib.plugins.parsers.trix
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    rdflib.plugins.parsers.pyMicrodata
    rdflib.plugins.parsers.pyRdfa

